==> apache-ignite-slim-2.9.0-bin.zip: apache-ignite-slim-2.9.0-bin/platforms/cpp/docs/search/variables_3.js <==
var searchData=
[
  ['ignite_5ferr_5fauthentication',['IGNITE_ERR_AUTHENTICATION',['../classignite_1_1IgniteError.html#af40bcc8942706ea9cca2d6a48d19cf95',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fbinary',['IGNITE_ERR_BINARY',['../classignite_1_1IgniteError.html#ac27e2575dc5d059d7d0a082ce146316a',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache',['IGNITE_ERR_CACHE',['../classignite_1_1IgniteError.html#a31df81fa7d4aba319ce9f143e95ade94',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5fatomic_5fupdate_5ftimeout',['IGNITE_ERR_CACHE_ATOMIC_UPDATE_TIMEOUT',['../classignite_1_1IgniteError.html#a8ac1ad51fbcab2e4d21a0a6e99d0869c',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5floader',['IGNITE_ERR_CACHE_LOADER',['../classignite_1_1IgniteError.html#ad5976c019d6d1fc3a05bf939aab90386',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5fpartial_5fupdate',['IGNITE_ERR_CACHE_PARTIAL_UPDATE',['../classignite_1_1IgniteError.html#ab4a18869477c13aa83773d0ee3856481',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5fwriter',['IGNITE_ERR_CACHE_WRITER',['../classignite_1_1IgniteError.html#add35054c7e4d1d12b423ac6ac91865fe',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcluster_5fgroup_5fempty',['IGNITE_ERR_CLUSTER_GROUP_EMPTY',['../classignite_1_1IgniteError.html#a28fc3b65aa0a8d9ff645f4dba500c0ef',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcluster_5ftopology',['IGNITE_ERR_CLUSTER_TOPOLOGY',['../classignite_1_1IgniteError.html#a40398c82b0d9b010bb8972c57dc8382e',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5fexecution_5frejected',['IGNITE_ERR_COMPUTE_EXECUTION_REJECTED',['../classignite_1_1IgniteError.html#a3e0a710f4dd1c6ba46f3f51b8e18b1ca',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5fjob_5ffailover',['IGNITE_ERR_COMPUTE_JOB_FAILOVER',['../classignite_1_1IgniteError.html#a2d176191431a474fb1e2d99cb38ba648',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5ftask_5fcancelled',['IGNITE_ERR_COMPUTE_TASK_CANCELLED',['../classignite_1_1IgniteError.html#a5e3e8079b47e65df9d4c3a3bad9a4cc1',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5ftask_5ftimeout',['IGNITE_ERR_COMPUTE_TASK_TIMEOUT',['../classignite_1_1IgniteError.html#a8e8e778572f0712f6ad56447f302ad38',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5fuser_5fundeclared_5fexception',['IGNITE_ERR_COMPUTE_USER_UNDECLARED_EXCEPTION',['../classignite_1_1IgniteError.html#aafd55bb6ed704c00530956c9b1854b04',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fentry_5fprocessor',['IGNITE_ERR_ENTRY_PROCESSOR',['../classignite_1_1IgniteError.html#a64488ed390cd6704a2250190da8c48c8',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ffuture_5fstate',['IGNITE_ERR_FUTURE_STATE',['../classignite_1_1IgniteError.html#ac2c981066994b73347674a335f305662',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fgeneric',['IGNITE_ERR_GENERIC',['../classignite_1_1IgniteError.html#abee4f1ca9ade2b8b4d0af780feea2577',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fillegal_5fargument',['IGNITE_ERR_ILLEGAL_ARGUMENT',['../classignite_1_1IgniteError.html#a98b95719803afd336779cac0cbc8e7c6',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fillegal_5fstate',['IGNITE_ERR_ILLEGAL_STATE',['../classignite_1_1IgniteError.html#ae1c2f989a415823b7ec1c1b9727b85b6',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5finterrupted',['IGNITE_ERR_INTERRUPTED',['../classignite_1_1IgniteError.html#a40b5b39f033920949d23e69ca92898c9',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fattach',['IGNITE_ERR_JVM_ATTACH',['../classignite_1_1IgniteError.html#a0d1f529b3e20e8984fba9c7f5ea8f2dc',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5finit',['IGNITE_ERR_JVM_INIT',['../classignite_1_1IgniteError.html#a4dc623486a94e45e097debc2341c86fb',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5flib_5fload_5ffailed',['IGNITE_ERR_JVM_LIB_LOAD_FAILED',['../classignite_1_1IgniteError.html#ad8bc5ec6fadc916c34fbd2e82a30632c',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5flib_5fnot_5ffound',['IGNITE_ERR_JVM_LIB_NOT_FOUND',['../classignite_1_1IgniteError.html#acd782e1fd0bd2189433f0c3197cb16a2',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fno_5fclass_5fdef_5ffound',['IGNITE_ERR_JVM_NO_CLASS_DEF_FOUND',['../classignite_1_1IgniteError.html#a51f3fcca5f8ec2261b55be9524601ae1',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fno_5fclasspath',['IGNITE_ERR_JVM_NO_CLASSPATH',['../classignite_1_1IgniteError.html#abdace31baa5d452183cb0d748a843c7e',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fno_5fsuch_5fmethod',['IGNITE_ERR_JVM_NO_SUCH_METHOD',['../classignite_1_1IgniteError.html#a6ff5f2b29a42ddb86a3be420ef8329e8',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fmemory',['IGNITE_ERR_MEMORY',['../classignite_1_1IgniteError.html#a792107910400c082f57c8c5aaab1f2e9',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fnetwork_5ffailure',['IGNITE_ERR_NETWORK_FAILURE',['../classignite_1_1IgniteError.html#a9c28e7328566b7270b531746b1187eca',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fsecure_5fconnection_5ffailure',['IGNITE_ERR_SECURE_CONNECTION_FAILURE',['../classignite_1_1IgniteError.html#ac44f812be3b54d8749f8123e67001a1f',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fsecurity',['IGNITE_ERR_SECURITY',['../classignite_1_1IgniteError.html#a2da52964515a0bfa432753f4a6459cc9',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fstd',['IGNITE_ERR_STD',['../classignite_1_1IgniteError.html#a3935199c119e50e7be615808bc6affa7',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5fheuristic',['IGNITE_ERR_TX_HEURISTIC',['../classignite_1_1IgniteError.html#a1e79b65d61f75bf1c3559c045e147955',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5foptimistic',['IGNITE_ERR_TX_OPTIMISTIC',['../classignite_1_1IgniteError.html#aef907367851f1b704e7f7f1c7d14db21',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5frollback',['IGNITE_ERR_TX_ROLLBACK',['../classignite_1_1IgniteError.html#aa6841c3a43f35fa877cb53cb6f10b092',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5ftimeout',['IGNITE_ERR_TX_TIMEOUT',['../classignite_1_1IgniteError.html#a3fa404daa57f7add992974b6235ed160',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5funknown',['IGNITE_ERR_UNKNOWN',['../classignite_1_1IgniteError.html#a7ecf71337aeb8a4a4b5eb67a25bfc67b',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5funsupported_5foperation',['IGNITE_ERR_UNSUPPORTED_OPERATION',['../classignite_1_1IgniteError.html#a9fe09b0273edf01de9f715fdfa66dea9',1,'ignite::IgniteError']]],
  ['ignite_5fsuccess',['IGNITE_SUCCESS',['../classignite_1_1IgniteError.html#a200551ef7921cf73b75d4ab94481e4e4',1,'ignite::IgniteError']]],
  ['ignitehome',['igniteHome',['../structignite_1_1IgniteConfiguration.html#a4a329a7a15ad3b291ea2dd34bf345511',1,'ignite::IgniteConfiguration']]]
];

==> apache-ignite-slim-2.11.1-bin.zip: apache-ignite-slim-2.11.1-bin/platforms/cpp/docs/search/variables_3.js <==
var searchData=
[
  ['ignite_5ferr_5fauthentication',['IGNITE_ERR_AUTHENTICATION',['../classignite_1_1IgniteError.html#af40bcc8942706ea9cca2d6a48d19cf95',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fbinary',['IGNITE_ERR_BINARY',['../classignite_1_1IgniteError.html#ac27e2575dc5d059d7d0a082ce146316a',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache',['IGNITE_ERR_CACHE',['../classignite_1_1IgniteError.html#a31df81fa7d4aba319ce9f143e95ade94',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5fatomic_5fupdate_5ftimeout',['IGNITE_ERR_CACHE_ATOMIC_UPDATE_TIMEOUT',['../classignite_1_1IgniteError.html#a8ac1ad51fbcab2e4d21a0a6e99d0869c',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5floader',['IGNITE_ERR_CACHE_LOADER',['../classignite_1_1IgniteError.html#ad5976c019d6d1fc3a05bf939aab90386',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5fpartial_5fupdate',['IGNITE_ERR_CACHE_PARTIAL_UPDATE',['../classignite_1_1IgniteError.html#ab4a18869477c13aa83773d0ee3856481',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcache_5fwriter',['IGNITE_ERR_CACHE_WRITER',['../classignite_1_1IgniteError.html#add35054c7e4d1d12b423ac6ac91865fe',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcluster_5fgroup_5fempty',['IGNITE_ERR_CLUSTER_GROUP_EMPTY',['../classignite_1_1IgniteError.html#a28fc3b65aa0a8d9ff645f4dba500c0ef',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcluster_5ftopology',['IGNITE_ERR_CLUSTER_TOPOLOGY',['../classignite_1_1IgniteError.html#a40398c82b0d9b010bb8972c57dc8382e',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5fexecution_5frejected',['IGNITE_ERR_COMPUTE_EXECUTION_REJECTED',['../classignite_1_1IgniteError.html#a3e0a710f4dd1c6ba46f3f51b8e18b1ca',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5fjob_5ffailover',['IGNITE_ERR_COMPUTE_JOB_FAILOVER',['../classignite_1_1IgniteError.html#a2d176191431a474fb1e2d99cb38ba648',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5ftask_5fcancelled',['IGNITE_ERR_COMPUTE_TASK_CANCELLED',['../classignite_1_1IgniteError.html#a5e3e8079b47e65df9d4c3a3bad9a4cc1',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5ftask_5ftimeout',['IGNITE_ERR_COMPUTE_TASK_TIMEOUT',['../classignite_1_1IgniteError.html#a8e8e778572f0712f6ad56447f302ad38',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fcompute_5fuser_5fundeclared_5fexception',['IGNITE_ERR_COMPUTE_USER_UNDECLARED_EXCEPTION',['../classignite_1_1IgniteError.html#aafd55bb6ed704c00530956c9b1854b04',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fentry_5fprocessor',['IGNITE_ERR_ENTRY_PROCESSOR',['../classignite_1_1IgniteError.html#a64488ed390cd6704a2250190da8c48c8',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ffuture_5fstate',['IGNITE_ERR_FUTURE_STATE',['../classignite_1_1IgniteError.html#ac2c981066994b73347674a335f305662',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fgeneric',['IGNITE_ERR_GENERIC',['../classignite_1_1IgniteError.html#abee4f1ca9ade2b8b4d0af780feea2577',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fillegal_5fargument',['IGNITE_ERR_ILLEGAL_ARGUMENT',['../classignite_1_1IgniteError.html#a98b95719803afd336779cac0cbc8e7c6',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fillegal_5fstate',['IGNITE_ERR_ILLEGAL_STATE',['../classignite_1_1IgniteError.html#ae1c2f989a415823b7ec1c1b9727b85b6',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5finterrupted',['IGNITE_ERR_INTERRUPTED',['../classignite_1_1IgniteError.html#a40b5b39f033920949d23e69ca92898c9',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fattach',['IGNITE_ERR_JVM_ATTACH',['../classignite_1_1IgniteError.html#a0d1f529b3e20e8984fba9c7f5ea8f2dc',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5finit',['IGNITE_ERR_JVM_INIT',['../classignite_1_1IgniteError.html#a4dc623486a94e45e097debc2341c86fb',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5flib_5fload_5ffailed',['IGNITE_ERR_JVM_LIB_LOAD_FAILED',['../classignite_1_1IgniteError.html#ad8bc5ec6fadc916c34fbd2e82a30632c',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5flib_5fnot_5ffound',['IGNITE_ERR_JVM_LIB_NOT_FOUND',['../classignite_1_1IgniteError.html#acd782e1fd0bd2189433f0c3197cb16a2',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fno_5fclass_5fdef_5ffound',['IGNITE_ERR_JVM_NO_CLASS_DEF_FOUND',['../classignite_1_1IgniteError.html#a51f3fcca5f8ec2261b55be9524601ae1',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fno_5fclasspath',['IGNITE_ERR_JVM_NO_CLASSPATH',['../classignite_1_1IgniteError.html#abdace31baa5d452183cb0d748a843c7e',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fjvm_5fno_5fsuch_5fmethod',['IGNITE_ERR_JVM_NO_SUCH_METHOD',['../classignite_1_1IgniteError.html#a6ff5f2b29a42ddb86a3be420ef8329e8',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fmemory',['IGNITE_ERR_MEMORY',['../classignite_1_1IgniteError.html#a792107910400c082f57c8c5aaab1f2e9',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fnetwork_5ffailure',['IGNITE_ERR_NETWORK_FAILURE',['../classignite_1_1IgniteError.html#a9c28e7328566b7270b531746b1187eca',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fsecure_5fconnection_5ffailure',['IGNITE_ERR_SECURE_CONNECTION_FAILURE',['../classignite_1_1IgniteError.html#ac44f812be3b54d8749f8123e67001a1f',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fsecurity',['IGNITE_ERR_SECURITY',['../classignite_1_1IgniteError.html#a2da52964515a0bfa432753f4a6459cc9',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5fstd',['IGNITE_ERR_STD',['../classignite_1_1IgniteError.html#a3935199c119e50e7be615808bc6affa7',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx',['IGNITE_ERR_TX',['../classignite_1_1IgniteError.html#a0db6fa62dc0cf1319c4145ea3049e8a9',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5fheuristic',['IGNITE_ERR_TX_HEURISTIC',['../classignite_1_1IgniteError.html#a1e79b65d61f75bf1c3559c045e147955',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5foptimistic',['IGNITE_ERR_TX_OPTIMISTIC',['../classignite_1_1IgniteError.html#aef907367851f1b704e7f7f1c7d14db21',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5frollback',['IGNITE_ERR_TX_ROLLBACK',['../classignite_1_1IgniteError.html#aa6841c3a43f35fa877cb53cb6f10b092',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5fthis_5fthread',['IGNITE_ERR_TX_THIS_THREAD',['../classignite_1_1IgniteError.html#a1322043eba14513b228adae0368cd245',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5ftx_5ftimeout',['IGNITE_ERR_TX_TIMEOUT',['../classignite_1_1IgniteError.html#a3fa404daa57f7add992974b6235ed160',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5funknown',['IGNITE_ERR_UNKNOWN',['../classignite_1_1IgniteError.html#a7ecf71337aeb8a4a4b5eb67a25bfc67b',1,'ignite::IgniteError']]],
  ['ignite_5ferr_5funsupported_5foperation',['IGNITE_ERR_UNSUPPORTED_OPERATION',['../classignite_1_1IgniteError.html#a9fe09b0273edf01de9f715fdfa66dea9',1,'ignite::IgniteError']]],
  ['ignite_5fsuccess',['IGNITE_SUCCESS',['../classignite_1_1IgniteError.html#a200551ef7921cf73b75d4ab94481e4e4',1,'ignite::IgniteError']]],
  ['ignitehome',['igniteHome',['../structignite_1_1IgniteConfiguration.html#a4a329a7a15ad3b291ea2dd34bf345511',1,'ignite::IgniteConfiguration']]]
];
